@@ -2,6 +2,7 @@ import datetime
 from typing import TYPE_CHECKING
 from travelperk_python_api_types.trips.trips.trips import Trips
 from .trips_input_params import TripsInputParams
+from travelperk_http_python.dataclass_wrapper.dataclass_wrapper import DataclassWrapper
 
 if TYPE_CHECKING:
     from travelperk_http_python.api.travelperk import TravelPerk
@@ -19,10 +20,9 @@ class TripsQuery:
         return getattr(self.travelperk, method)(url, params)
 
     def get(self) -> Trips:
-        return Trips(
-            **self.execute(
-                "get", "/".join(["trips"]) + "?" + self.params.as_url_param()
-            )
+        return DataclassWrapper.wrap(
+            Trips,
+            self.execute("get", "/".join(["trips"]) + "?" + self.params.as_url_param()),
         )
 
     def set_status(self, status: str) -> "TripsQuery":
